@@ -79,7 +79,7 @@ Returns the respective component of the parsed IRI.
 package IRI {
 	use v5.14;
 	use warnings;
-	our $VERSION	= '0.004_01';
+	our $VERSION	= '0.004_02';
 	use Moo;
 	use MooX::HandlesVia;
 	use Types::Standard qw(Str InstanceOf HashRef Bool);
@@ -140,7 +140,7 @@ package IRI {
 		}
 	}
 	
-	before [qw(components as_string abs resolved_components)] => sub {
+	before [qw(components as_string abs resolved_components scheme host port user path fragment query)] => sub {
 		my $self	= shift;
 		if (not $self->_initialized) {
 # 			warn "Lazily initializing IRI";
